@@ -5,12 +5,14 @@ use warnings;
 use Carp qw/croak/;
 use XSLoader;
 
-our $VERSION= '4.025'; # Don't forget to update the TestCompat set for testing against installed decoders!
+our $VERSION= '5.000_001'; # Don't forget to update the TestCompat set for testing against installed decoders!
 our $XS_VERSION= $VERSION; $VERSION= eval $VERSION;
 
 # not for public consumption, just for testing.
 ( my $num_version= $VERSION ) =~ s/_//;
-my $TestCompat= [ map sprintf( "%.2f", $_ / 100 ), reverse( 400 .. int( $num_version * 100 ) ) ]; # compat with 4.00 to ...
+my $TestCompat= [ map sprintf( "%.2f", $_ / 100 ),
+                  reverse( 400 .. int( $num_version * 100 ) )
+                ]; # compat with 4.00 to ...
 sub _test_compat { return ( @$TestCompat, $VERSION ) }
 
 # Make sure to keep these constants in sync with the C code in srl_encoder.c.
@@ -436,6 +438,15 @@ but at the cost of potential action at a distance due to the aliasing.
 I<Beware:> The test suite currently does not cover this option as well as it
 probably should. Patches welcome.
 
+=head3 use_standard_double
+
+This option can be used to force Perls built with uselongdouble or quadmath
+to use DOUBLE instead of the native floating point. This can be helpful
+interoperating with Perls which do not support larger sized floats. Note
+that "uselongdouble" means different things in different places, so this
+option may be helpful for such builds. We do not enable this option by default
+for backwards compatibility reasons, and because doing so would lose precision.
+
 =head3 protocol_version
 
 Specifies the version of the Sereal protocol to emit. Valid are integers
@@ -847,6 +858,13 @@ Sereal currently will choose the *string* value when it detects these items.
 
 It is possible that a future release of the protocol will fix these issues.
 
+=item Booleans
+
+As of Perl 5.36 and protocol version 5 Sereal now supports booleans. The new
+tags SRL_HDR_YES and SRL_HDR_NO now represent perl bools, the old special
+variables that SRL_HDR_TRUE and SRL_HDR_FALSE may still be generated, but beyond
+being readonly these are equivalent to SRL_HDR_YES and SRL_HDR_NO.
+
 =back
 
 =head1 BUGS, CONTACT AND SUPPORT
